@@ -142,6 +142,9 @@ def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggre
       time_col = 'fundingTime'
       try:
         print(f'requesting funding {time_col} between {startTime} and {endTime}')
+        print(f'requesting {type(startTime)} {type(endTime)} {startTime} {endTime}')
+        startTime =int(startTime)
+        endTime=int(endTime)
         output = pd.concat([output, pd.DataFrame(client.futures_funding_rate(symbol = symbol, startTime = startTime, endTime = endTime, limit = 1000))])
         time.sleep(sleeping_time)
       except json.decoder.JSONDecodeError:
@@ -157,7 +160,9 @@ def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggre
       try:
         print(f'requesting trades {time_col} between {startTime} and {endTime}')
         time.sleep(sleeping_time)
-
+        print(f'requesting {type(startTime)} {type(endTime)} {startTime} {endTime}')
+        startTime =int(startTime)
+        endTime=int(endTime)
         tmp = pd.DataFrame(client.futures_account_trades(limit = 1000, startTime = startTime, endTime = endTime))
         output = pd.concat([output, tmp])
       except json.decoder.JSONDecodeError:
@@ -174,7 +179,9 @@ def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggre
       try:
         print(f'requesting futures_kline {time_col} between {startTime} and {endTime}')
         time.sleep(sleeping_time)
-
+        print(f'requesting {type(startTime)} {type(endTime)} {startTime} {endTime}')
+        startTime =int(startTime)
+        endTime=int(endTime)
         output = pd.concat([output, pd.DataFrame(client.futures_klines(symbol = symbol, interval = aggreg, startTime = startTime, endTime = endTime, limit = 1000))])
       except json.decoder.JSONDecodeError:
         print('Could not convert to Json. Passing @time:', startTime)
@@ -196,7 +203,9 @@ def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggre
       try:
         print(f'requesting income history {time_col} between {startTime} and {endTime}')
         time.sleep(sleeping_time)
-
+        print(f'requesting {type(startTime)} {type(endTime)} {startTime} {endTime}')
+        startTime =int(startTime)
+        endTime=int(endTime)
         output = pd.concat([output, pd.DataFrame(client.futures_income_history(startTime = startTime, endTime=endTime, limit = 1000))])
 
       except json.decoder.JSONDecodeError:
@@ -216,6 +225,9 @@ def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggre
       try:
         print(f'requesting income historical kline {time_col} between {startTime} and {endTime}')
         time.sleep(sleeping_time)
+        print(f'requesting {type(startTime)} {type(endTime)} {startTime} {endTime}')
+        startTime =int(startTime)
+        endTime=int(endTime)
         output = pd.concat([output, pd.DataFrame(client.get_historical_klines(symbol = symbol, interval = aggreg, start_str = startTime, end_str = endTime, limit = 500))])
       except json.decoder.JSONDecodeError:
         print('Could not convert to Json. Passing @time:', startTime)
@@ -767,7 +779,7 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
 
         x = td[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth', 'open_eth_cc', 'open_eth_bnc',
                 'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt', 'open_btc_cc', 'open_btc_bnc',
-                'valuation', 'fut_transfer_usdt_amount','wallet_balance',
+                'valuation', 'fut_transfer_usdt_amount','wallet_balance','pnl',
                 'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
                 'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]]
 
@@ -777,7 +789,7 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
                      'open_eth_cc', 'open_eth_exchange',
                      'quantity_traded_btc', 'avg_traded_price_btc', 'amount_traded_usd_btc', 'n_trades_btc',
                      'open_btc_cc', 'open_btc_exchange',
-                     'wallet_amount_usd', 'transfers_usd','wallet_binance_balance',
+                     'wallet_amount_usd', 'transfers_usd','wallet_binance_balance','pnl',
                      'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
                      'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]
 
